pub struct FileMode {
pub setuid: bool,
pub setgid: bool,
pub owner: Perms,
pub group: Perms,
pub other: Perms,
}Expand description
The file/dir permissions for owner/group/everyone else.
Fields
setuid: boolExecutable files with this bit set will run with effective uid set to the uid of the file owner.
setgid: boolExecutable files with this bit set will run with effective gid set to the gid of the file owner.
owner: PermsThe permissions for the owner of the file.
group: PermsThe permissions for everyone who is not the owner, but in the group.
other: PermsThe permissions for everyone who is not the owner and not in the group.