Struct mtree::FileMode [−][src]
pub struct FileMode {
pub setuid: bool,
pub setgid: bool,
pub owner: Perms,
pub group: Perms,
pub other: Perms,
}The file/dir permissions for owner/group/everyone else.
Fields
setuid: bool
Executable files with this bit set will run with effective uid set to the uid of the file owner.
setgid: bool
Executable files with this bit set will run with effective gid set to the gid of the file owner.
owner: Perms
The permissions for the owner of the file.
group: Perms
The permissions for everyone who is not the owner, but in the group.
other: Perms
The permissions for everyone who is not the owner and not in the group.